## Code to run regressions and create tables #
# Paper: Competition and Contracting: The Effect of Competition Shocks on Alternative Work Arrangements in the U.S. Labor Market 1995-2005
# Author: Daniel Deibler
# Date Created: 8/7/2018

# The public use micro file (PUF) contains the following information:

# demographics - data for means tables and reduced form evidence.
# demographics_codebook - Codebook (with variable and description) for demographics.

# trade_state - data for running state-level regressions.
# trade_state_codebook - Codebook (with variable and description) for trade_state.

# trade_micro - data for running micro-level regressions.
# trade_micro_codebook - Codebook (with variable and description) for trade_micro.


# Code to load relevant libraries #
rm(list=ls(all=TRUE))
library(doBy)
library(plyr)
library(foreign)
library(AER)

# Insert the working directory for the data file below #
setwd("")
load("DEIBLER_PUMS.RData")


# Below is the code to run the regressions for each table used in the paper #

#### TABLE 1: Means and standard deviations ####

res <- t(summaryBy(famsize+nchild+nsibs+age+female+hispanic+yrs_educ+multjob+numjob+hoursvary1+uhrswork1+fulltime+met
                   ~ contract, data = demographics[demographics$working==1,], 
                   FUN = function(x) { c(m = mean(x), s = sd(x), med = median(x),length=length(x))}))

res2 <- t(summaryBy(wage
                    ~ contract, data = demographics[is.na(demographics$wage)==FALSE,], 
                    FUN = function(x) { c(m = mean(x), s = sd(x), med = median(x),length=length(x))}))

res3 <- t(summaryBy(empl_ins
                    ~ contract, data = demographics[is.na(demographics$empl_ins)==FALSE,], 
                    FUN = function(x) { c(m = mean(x), s = sd(x), med = median(x),length=length(x))}))

res4 <- t(summaryBy(pension
                    ~ contract, data = demographics[is.na(demographics$pension)==FALSE,], 
                    FUN = function(x) { c(m = mean(x), s = sd(x), med = median(x),length=length(x))}))

res5 <- t(summaryBy(switch_after
                    ~ contract, data = demographics[is.na(demographics$switch_after)==FALSE,], 
                    FUN = function(x) { c(m = mean(x), s = sd(x), med = median(x),length=length(x))}))

##### Table 2: Demographic Predictors of Contract Type #####

reg1 <- glm(contractco ~ race+yrs_educ+hispanic+famsize+female+met+citizen+age+nchild,family=binomial(link='logit'),data=demographics[demographics$working==1,])
reg2 <- glm(temp_agency ~ race+yrs_educ+hispanic+famsize+female+met+citizen+age+nchild,family=binomial(link='logit'),data=demographics[demographics$working==1,])
reg3 <- glm(oncall ~ race+yrs_educ+hispanic+famsize+female+met+citizen+age+nchild,family=binomial(link='logit'),data=demographics[demographics$working==1,])
reg4 <- glm(ind_con ~ race+yrs_educ+hispanic+famsize+female+met+citizen+age+nchild,family=binomial(link='logit'),data=demographics[demographics$working==1,])

#### Table 3: Outcomes from Contracts #####

reg1 <- lm(hoursvary1 ~ contract + age+marst+yrs_educ+faminc+race+uhrswork1+ind_fac+occ_fac+metarea,data=demographics[demographics$working==1 & is.na(demographics$highinc)==FALSE,])
reg2 <- lm(wageinc ~ contract + age+marst+yrs_educ+uhrswork1+race+ind_fac+occ_fac+metarea,data=demographics[demographics$working==1,])
reg3 <- lm(highinc ~ contract + age+marst+yrs_educ+uhrswork1+race+ind_fac+occ_fac+metarea,data=demographics[demographics$working==1,])
reg4 <- lm(empl_ins ~ contract + age+marst+faminc+yrs_educ+race+uhrswork1+ind_fac+occ_fac+metarea,data=demographics[demographics$working==1,])
reg5 <- lm(multjob ~ contract + age+marst+faminc+yrs_educ+race+uhrswork1+ind_fac+occ_fac+metarea,data=demographics[demographics$working==1  & is.na(demographics$highinc)==FALSE,])


### Footnotes about total income/hours ####
reg7 <- lm(totinc ~ contract + age+marst+yrs_educ+uhrswork1+race+ind_fac+occ_fac+metarea,data=demographics[demographics$working==1 & demographics$totinc<99999999,])
reg8 <- lm(uhrswork1 ~ contract + age+marst+yrs_educ+race+ind_fac+occ_fac+metarea+faminc,data=demographics[demographics$working==1,])

#### Table 4: Effect of Competition Shocks, State Level #####

ivreg1 <- ivreg(d_awa_w ~ d_w + tt | d_otw +tt,data=trade_state)
ivreg2 <- ivreg(d_awa_w ~ d_w + m_sh +tt| d_otw+m_sh +tt,data=trade_state)
ivreg3 <- ivreg(d_awa_w ~ d_w + m_sh + dum_census+tt| d_otw+m_sh+dum_census +tt,data=trade_state)
ivreg4 <- ivreg(d_awa_w ~ d_w + m_sh + dum_census + l_sh_popedu_c + l_sh_popfborn+l_sh_empl_f+tt 
                | d_otw+m_sh+dum_census + l_sh_popedu_c +l_sh_popfborn+l_sh_empl_f +tt,data=trade_state)
ivreg5 <- ivreg(d_awa_w ~ d_w + m_sh + dum_census + l_sh_popedu_c +l_sh_popfborn+l_sh_empl_f  + pct_rt+tt|
                  d_otw + m_sh + dum_census + l_sh_popedu_c +l_sh_popfborn+l_sh_empl_f  + pct_rt+tt,data=trade_state)



##### Table 5: Effect of Competition Shock - By Contract #####

ivreg1 <- ivreg(contractco ~ d_w + m_sh + dum_census + l_sh_popedu_c +l_sh_popfborn+l_sh_empl_f  + pct_rt +tt
                | d_otw+m_sh+dum_census + l_sh_popedu_c +l_sh_popfborn+l_sh_empl_f + pct_rt +tt,data=trade_state)
ivreg2 <- ivreg(temp_agency ~ d_w + m_sh + dum_census + l_sh_popedu_c +l_sh_popfborn+l_sh_empl_f  + pct_rt +tt
                | d_otw+m_sh+dum_census + l_sh_popedu_c +l_sh_popfborn+l_sh_empl_f + pct_rt +tt,data=trade_state)
ivreg3 <- ivreg(ind_con ~ d_w + m_sh + dum_census + l_sh_popedu_c +l_sh_popfborn+l_sh_empl_f  + pct_rt +tt
                | d_otw+m_sh+dum_census + l_sh_popedu_c +l_sh_popfborn+l_sh_empl_f + pct_rt +tt,data=trade_state)
ivreg4 <- ivreg(oncall ~ d_w + m_sh + dum_census + l_sh_popedu_c +l_sh_popfborn+l_sh_empl_f  + pct_rt +tt
                | d_otw+m_sh+dum_census + l_sh_popedu_c +l_sh_popfborn+l_sh_empl_f + pct_rt +tt,data=trade_state)



#### Tables 6 and 7: Effect of AWA Share on Inequality, OLS and IV #####

# OLS #
reg2 <- lm(Top5_adj ~ manu_w+d_awa_w+m_sh+dum_census + l_sh_popedu_c +l_sh_popfborn+l_sh_empl_f + pct_rt +tt,data=trade_state)
reg3 <- lm(Top1_adj ~ manu_w+d_awa_w+m_sh+dum_census + l_sh_popedu_c +l_sh_popfborn+l_sh_empl_f + pct_rt +tt,data=trade_state)
reg4 <- lm(Theil ~ manu_w+d_awa_w+m_sh+dum_census + l_sh_popedu_c +l_sh_popfborn+l_sh_empl_f + pct_rt +tt,data=trade_state)
reg5 <- lm(Gini ~ manu_w+d_awa_w+m_sh+dum_census + l_sh_popedu_c +l_sh_popfborn+l_sh_empl_f + pct_rt +tt,data=trade_state)

# IV #
ivreg2 <- ivreg(Top5_adj ~ manu_w+d_awa_w+m_sh+dum_census + l_sh_popedu_c +l_sh_popfborn+l_sh_empl_f + pct_rt +tt|
                  manu_w+d_w+m_sh+dum_census + l_sh_popedu_c +l_sh_popfborn+l_sh_empl_f + pct_rt +tt,data=trade_state)
ivreg3 <- ivreg(Top1_adj ~ manu_w+d_awa_w+m_sh+dum_census + l_sh_popedu_c +l_sh_popfborn+l_sh_empl_f + pct_rt +tt|
                  manu_w+d_w+m_sh+dum_census + l_sh_popedu_c +l_sh_popfborn+l_sh_empl_f + pct_rt +tt,data=trade_state)
ivreg4 <- ivreg(Theil ~ manu_w+d_awa_w+m_sh+dum_census + l_sh_popedu_c +l_sh_popfborn+l_sh_empl_f + pct_rt +tt|
                  manu_w+d_w+m_sh+dum_census + l_sh_popedu_c +l_sh_popfborn+l_sh_empl_f + pct_rt +tt,data=trade_state)
ivreg5 <- ivreg(Gini ~ manu_w+d_awa_w+m_sh+dum_census + l_sh_popedu_c +l_sh_popfborn+l_sh_empl_f + pct_rt +tt|
                  manu_w+d_w+m_sh+dum_census + l_sh_popedu_c +l_sh_popfborn+l_sh_empl_f + pct_rt +tt,data=trade_state)




##### Tables 8 and 9 - Effect of Trade Shocks - Micro-Level #####
ivreg1 <- ivreg(awa ~ d_w | d_otw,data=trade_micro)
ivreg2 <- ivreg(awa ~ d_w + yearfac + education_fa | d_otw + yearfac + education_fa,data=trade_micro)
ivreg3 <- ivreg(awa ~ d_w + yearfac + education_fa + race + hispan + citizen | d_otw + yearfac + education_fa + race + hispan + citizen,data=trade_micro)
ivreg4 <- ivreg(awa ~ d_w + yearfac + education_fa + race + hispan + citizen + age | d_otw + yearfac + education_fa + race + hispan + citizen+age,data=trade_micro)
ivreg5 <- ivreg(awa ~ d_w + yearfac + education_fa + race + hispan + citizen + age + occ_agg + sex| d_otw + yearfac + education_fa + race + hispan + citizen + age + occ_agg + sex,data=trade_micro)


ivreg1 <- ivreg(ind_con ~ d_w + yearfac + education_fa + race + hispan + citizen + age + occ_agg + sex| d_otw + yearfac + education_fa + race + hispan + citizen + age + occ_agg + sex,data=trade_micro[trade_micro$working==1,])
ivreg2 <- ivreg(contractco ~ d_w + yearfac + education_fa + race + hispan + citizen + age + occ_agg + sex| d_otw + yearfac + education_fa + race + hispan + citizen + age + occ_agg + sex,data=trade_micro[trade_micro$working==1,])
ivreg3 <- ivreg(temp_agency ~ d_w  + d_w + yearfac + education_fa + race + hispan + citizen + age + occ_agg + sex| d_otw + yearfac + education_fa + race + hispan + citizen + age + occ_agg + sex,data=trade_micro[trade_micro$working==1,])
ivreg4 <- ivreg(oncall ~ d_w + yearfac + education_fa + race + hispan + citizen + age + occ_agg + sex| d_otw + yearfac + education_fa + race + hispan + citizen + age + occ_agg + sex,data=trade_micro[trade_micro$working==1,])


##### Table 10 - Effect of Trade Shocks on Economic Outcomes, non-AWA employees #####

ivreg1 <- ivreg(uhrswork1 ~ d_w + yearfac + education_fa + race + hispan + citizen + age + occ_agg + sex| d_otw + yearfac + education_fa + race + hispan + citizen + age + occ_agg + sex,data=trade_micro[trade_micro$working==1 & trade_micro$awa==0,])
ivreg2 <- ivreg(highinc ~ d_w + yearfac + education_fa + race + hispan + citizen + age + occ_agg + sex| d_otw + yearfac + education_fa + race + hispan + citizen + age + occ_agg + sex,data=trade_micro[trade_micro$working==1 & trade_micro$awa==0,])
ivreg3 <- ivreg(hoursvary1 ~ d_w + yearfac + education_fa + race + hispan + citizen + age + occ_agg + sex| d_otw + yearfac + education_fa + race + hispan + citizen + age + occ_agg + sex,data=trade_micro[trade_micro$working==1 & trade_micro$awa==0,])

# Merging insurance information for final regression #
ins <- demographics[,c("cpsidp","empl_ins")]
ins <- merge(ins,trade_micro,by="cpsidp")

ivreg4 <- ivreg(empl_ins ~ d_w + yearfac + education_fa + race + hispan + citizen + age + occ_agg + sex| d_otw + yearfac + education_fa + race + hispan + citizen + age + occ_agg + sex,data=ins[ins$working==1 & ins$awa==0,])

